shishi-commit
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

CVS shishi/gl


From: shishi-commit
Subject: CVS shishi/gl
Date: Thu, 26 May 2005 17:07:54 +0200

Update of /home/cvs/shishi/gl
In directory dopio:/tmp/cvs-serv5438/gl

Modified Files:
        Makefile.am alloca_.h allocsa.c allocsa.h asnprintf.c 
        asprintf.c base64.c base64.h error.c error.h gai_strerror.c 
        getaddrinfo.c getaddrinfo.h getdate.h getdate.y 
        getdomainname.c getdomainname.h gethostname.c getline.c 
        getline.h getndelim2.c getndelim2.h getopt.c getopt1.c 
        getopt_.h getopt_int.h getpass.c getpass.h getsubopt.c 
        getsubopt.h gettext.h gettime.c gettimeofday.c mktime.c 
        printf-args.c printf-args.h printf-parse.c printf-parse.h 
        progname.c progname.h readlink.c realloc.c setenv.c setenv.h 
        stdbool_.h strcase.h strcasecmp.c strchrnul.c strchrnul.h 
        strdup.c strdup.h strndup.c strndup.h strnlen.c strtok_r.c 
        strtok_r.h time_r.c time_r.h timegm.c timegm.h timespec.h 
        unsetenv.c vasnprintf.c vasnprintf.h vasprintf.c vasprintf.h 
        xalloc.h xasprintf.c xgetdomainname.c xgetdomainname.h 
        xgethostname.c xmalloc.c xreadlink.c xreadlink.h xsize.h 
        xstrndup.c xstrndup.h xvasprintf.c xvasprintf.h 
Log Message:
Update.

--- /home/cvs/shishi/gl/Makefile.am     2005/03/21 22:38:02     1.58
+++ /home/cvs/shishi/gl/Makefile.am     2005/05/26 15:07:53     1.59
@@ -8,8 +8,8 @@
 # the same distribution terms as the rest of that program.
 #
 # Generated by gnulib-tool.
-# Invoked as: gnulib-tool --import --automatic-prototypes
-# Reproduce by: gnulib-tool --import --dir=. --lib=libgnu --source-base=gl 
--m4-base=gl/m4 --libtool  alloca-opt allocsa base64 error extensions 
getaddrinfo getdate getdomainname gethostname getline getopt getpass getsubopt 
gettext gettime gettimeofday mktime progname readlink realloc restrict setenv 
size_max stdbool strcase strchrnul strdup strndup strnlen strtok_r timegm 
time_r timespec vasnprintf vasprintf xalloc xgetdomainname xgethostname 
xreadlink xsize xstrndup xvasprintf
+# Invoked as: gnulib-tool --import
+# Reproduce by: gnulib-tool --import --dir=. --lib=libgnu --source-base=gl 
--m4-base=gl/m4 --aux-dir=. --libtool  alloca-opt allocsa base64 error 
extensions getaddrinfo getdate getdomainname gethostname getline getopt getpass 
getsubopt gettext gettime gettimeofday mktime progname readlink realloc 
restrict setenv size_max stdbool strcase strchrnul strdup strndup strnlen 
strtok_r timegm time_r timespec vasnprintf vasprintf xalloc xgetdomainname 
xgethostname xreadlink xsize xstrndup xvasprintf
 
 AUTOMAKE_OPTIONS = 1.5 gnits no-dependencies
 
@@ -63,6 +63,7 @@
 
 BUILT_SOURCES += getdate.c
 MAINTAINERCLEANFILES += getdate.c
+EXTRA_DIST += getdate.c
 
 ## end   gnulib module getdate
 
@@ -206,7 +207,7 @@
 
 ## begin gnulib module xvasprintf
 
-libgnu_la_SOURCES += xvasprintf.h xvasprintf.c xasprintf.c 
+libgnu_la_SOURCES += xvasprintf.h xvasprintf.c xasprintf.c
 
 ## end   gnulib module xvasprintf
 
--- /home/cvs/shishi/gl/alloca_.h       2004/12/19 15:37:31     1.6
+++ /home/cvs/shishi/gl/alloca_.h       2005/05/26 15:07:53     1.7
@@ -15,7 +15,7 @@
 
    You should have received a copy of the GNU General Public
    License along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
    USA.  */
 
 /* Avoid using the symbol _ALLOCA_H here, as Bison assumes _ALLOCA_H
--- /home/cvs/shishi/gl/allocsa.c       2004/04/18 12:10:19     1.1
+++ /home/cvs/shishi/gl/allocsa.c       2005/05/26 15:07:53     1.2
@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
--- /home/cvs/shishi/gl/allocsa.h       2004/11/11 18:58:35     1.3
+++ /home/cvs/shishi/gl/allocsa.h       2005/05/26 15:07:53     1.4
@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifndef _ALLOCSA_H
 #define _ALLOCSA_H
--- /home/cvs/shishi/gl/asnprintf.c     2003/08/22 17:48:49     1.2
+++ /home/cvs/shishi/gl/asnprintf.c     2005/05/26 15:07:53     1.3
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
--- /home/cvs/shishi/gl/asprintf.c      2003/08/22 17:48:49     1.2
+++ /home/cvs/shishi/gl/asprintf.c      2005/05/26 15:07:53     1.3
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
--- /home/cvs/shishi/gl/base64.c        2005/01/02 00:18:38     1.4
+++ /home/cvs/shishi/gl/base64.c        2005/05/26 15:07:53     1.5
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 /* Written by Simon Josefsson.  Partially adapted from GNU MailUtils
  * (mailbox/filter_trans.c, as of 2004-11-28).  Improved by review
--- /home/cvs/shishi/gl/base64.h        2005/01/02 00:18:38     1.3
+++ /home/cvs/shishi/gl/base64.h        2005/05/26 15:07:53     1.4
@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifndef BASE64_H
 # define BASE64_H
--- /home/cvs/shishi/gl/error.c 2005/01/02 00:18:38     1.8
+++ /home/cvs/shishi/gl/error.c 2005/05/26 15:07:53     1.9
@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 /* Written by David MacKenzie <address@hidden>.  */
 
--- /home/cvs/shishi/gl/error.h 2003/10/16 10:53:29     1.3
+++ /home/cvs/shishi/gl/error.h 2005/05/26 15:07:53     1.4
@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifndef _ERROR_H
 #define _ERROR_H 1
--- /home/cvs/shishi/gl/gai_strerror.c  2005/01/29 01:04:45     1.2
+++ /home/cvs/shishi/gl/gai_strerror.c  2005/05/26 15:07:53     1.3
@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #include <stdio.h>
 #include <netdb.h>
--- /home/cvs/shishi/gl/getaddrinfo.c   2004/11/10 18:10:30     1.2
+++ /home/cvs/shishi/gl/getaddrinfo.c   2005/05/26 15:07:53     1.3
@@ -1,5 +1,5 @@
 /* Get address information (partial implementation).
-   Copyright (C) 1997, 2001, 2002, 2004 Free Software Foundation, Inc.
+   Copyright (C) 1997, 2001, 2002, 2004, 2005 Free Software Foundation, Inc.
    Contributed by Simon Josefsson <address@hidden>.
 
    This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #if HAVE_CONFIG_H
 # include <config.h>
@@ -74,14 +74,10 @@
   if (hints && !validate_family (hints->ai_family))
     return EAI_FAMILY;
 
-  if (hints && hints->ai_socktype)
-    /* FIXME: Support more socket types. */
-    return EAI_SOCKTYPE;
-
   if (hints &&
-      hints->ai_protocol != SOCK_STREAM && hints->ai_protocol != SOCK_DGRAM)
-    /* FIXME: Support other protocols. */
-    return EAI_SERVICE;                /* FIXME: Better return code? */
+      hints->ai_socktype != SOCK_STREAM && hints->ai_socktype != SOCK_DGRAM)
+    /* FIXME: Support other socktype. */
+    return EAI_SOCKTYPE; /* FIXME: Better return code? */
 
   if (!nodename)
     /* FIXME: Support server bind mode. */
@@ -90,7 +86,7 @@
   if (servname)
     {
       const char *proto =
-       (hints && hints->ai_protocol == SOCK_DGRAM) ? "udp" : "tcp";
+       (hints && hints->ai_socktype == SOCK_DGRAM) ? "udp" : "tcp";
 
       /* FIXME: Use getservbyname_r if available. */
       se = getservbyname (servname, proto);
@@ -171,6 +167,8 @@
       return EAI_NODATA;
     }
 
+  tmp->ai_protocol = (hints) ? hints->ai_protocol : 0;
+  tmp->ai_socktype = (hints) ? hints->ai_socktype : 0;
   tmp->ai_addr->sa_family = he->h_addrtype;
 
   /* FIXME: If more than one address, create linked list of addrinfo's. */
--- /home/cvs/shishi/gl/getaddrinfo.h   2004/11/09 18:18:50     1.1
+++ /home/cvs/shishi/gl/getaddrinfo.h   2005/05/26 15:07:53     1.2
@@ -1,5 +1,5 @@
 /* Get address information.
-   Copyright (C) 1996-2002, 2003, 2004 Free Software Foundation, Inc.
+   Copyright (C) 1996-2002, 2003, 2004, 2005 Free Software Foundation, Inc.
    Contributed by Simon Josefsson <address@hidden>.
 
    This program is free software; you can redistribute it and/or modify
@@ -14,20 +14,19 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifndef GETADDRINFO_H
 # define GETADDRINFO_H
 
-/* Get getaddrinfo declarations, if available. */
+/* Get getaddrinfo declarations, if available.  Also get 'socklen_t',
+   and 'struct sockaddr' via sys/types.h which are used below. */
+# include <sys/types.h>
 # include <sys/socket.h>
 # include <netdb.h>
 
 # if defined HAVE_GETADDRINFO && !HAVE_GETADDRINFO
 
-/* Get socklen_t, struct sockaddr. */
-#  include <sys/types.h>
-
 /* Structure to contain information about address of a service provider.  */
 struct addrinfo
 {
--- /home/cvs/shishi/gl/getdate.h       2004/04/18 12:10:19     1.2
+++ /home/cvs/shishi/gl/getdate.h       2005/05/26 15:07:53     1.3
@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #if HAVE_CONFIG_H
 # include <config.h>
--- /home/cvs/shishi/gl/getdate.y       2005/03/14 14:32:13     1.14
+++ /home/cvs/shishi/gl/getdate.y       2005/05/26 15:07:53     1.15
@@ -16,7 +16,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 /* Originally written by Steven M. Bellovin <address@hidden> while
    at the University of North Carolina at Chapel Hill.  Later tweaked by
@@ -175,12 +175,13 @@
   long int rel_seconds;
   long int rel_ns;
 
-  /* Counts of nonterminals of various flavors parsed so far.  */
+  /* Presence or counts of nonterminals of various flavors parsed so far.  */
   bool timespec_seen;
+  bool rels_seen;
   size_t dates_seen;
   size_t days_seen;
   size_t local_zones_seen;
-  size_t rels_seen;
+  size_t dsts_seen;
   size_t times_seen;
   size_t zones_seen;
 
@@ -201,8 +202,8 @@
 %parse-param { parser_control *pc }
 %lex-param { parser_control *pc }
 
-/* This grammar has 14 shift/reduce conflicts. */
-%expect 14
+/* This grammar has 20 shift/reduce conflicts. */
+%expect 20
 
 %union
 {
@@ -255,7 +256,7 @@
   | day
       { pc->days_seen++; }
   | rel
-      { pc->rels_seen++; }
+      { pc->rels_seen = true; }
   | number
   ;
 
@@ -306,14 +307,22 @@
 
 local_zone:
     tLOCAL_ZONE
-      { pc->local_isdst = $1; }
+      {
+       pc->local_isdst = $1;
+       pc->dsts_seen += (0 < $1);
+      }
   | tLOCAL_ZONE tDST
-      { pc->local_isdst = $1 < 0 ? 1 : $1 + 1; }
+      {
+       pc->local_isdst = 1;
+       pc->dsts_seen += (0 < $1) + 1;
+      }
   ;
 
 zone:
     tZONE
       { pc->time_zone = $1; }
+  | tZONE relunit_snumber
+      { pc->time_zone = $1; pc->rels_seen = true; }
   | tZONE tSNUMBER o_colon_minutes
       { pc->time_zone = $1 + time_zone_hhmm ($2, $3); }
   | tDAYZONE
@@ -437,54 +446,58 @@
       { pc->rel_year += $1 * $2; }
   | tUNUMBER tYEAR_UNIT
       { pc->rel_year += $1.value * $2; }
-  | tSNUMBER tYEAR_UNIT
-      { pc->rel_year += $1.value * $2; }
   | tYEAR_UNIT
       { pc->rel_year += $1; }
   | tORDINAL tMONTH_UNIT
       { pc->rel_month += $1 * $2; }
   | tUNUMBER tMONTH_UNIT
       { pc->rel_month += $1.value * $2; }
-  | tSNUMBER tMONTH_UNIT
-      { pc->rel_month += $1.value * $2; }
   | tMONTH_UNIT
       { pc->rel_month += $1; }
   | tORDINAL tDAY_UNIT
       { pc->rel_day += $1 * $2; }
   | tUNUMBER tDAY_UNIT
       { pc->rel_day += $1.value * $2; }
-  | tSNUMBER tDAY_UNIT
-      { pc->rel_day += $1.value * $2; }
   | tDAY_UNIT
       { pc->rel_day += $1; }
   | tORDINAL tHOUR_UNIT
       { pc->rel_hour += $1 * $2; }
   | tUNUMBER tHOUR_UNIT
       { pc->rel_hour += $1.value * $2; }
-  | tSNUMBER tHOUR_UNIT
-      { pc->rel_hour += $1.value * $2; }
   | tHOUR_UNIT
       { pc->rel_hour += $1; }
   | tORDINAL tMINUTE_UNIT
       { pc->rel_minutes += $1 * $2; }
   | tUNUMBER tMINUTE_UNIT
       { pc->rel_minutes += $1.value * $2; }
-  | tSNUMBER tMINUTE_UNIT
-      { pc->rel_minutes += $1.value * $2; }
   | tMINUTE_UNIT
       { pc->rel_minutes += $1; }
   | tORDINAL tSEC_UNIT
       { pc->rel_seconds += $1 * $2; }
   | tUNUMBER tSEC_UNIT
       { pc->rel_seconds += $1.value * $2; }
-  | tSNUMBER tSEC_UNIT
-      { pc->rel_seconds += $1.value * $2; }
   | tSDECIMAL_NUMBER tSEC_UNIT
       { pc->rel_seconds += $1.tv_sec * $2; pc->rel_ns += $1.tv_nsec * $2; }
   | tUDECIMAL_NUMBER tSEC_UNIT
       { pc->rel_seconds += $1.tv_sec * $2; pc->rel_ns += $1.tv_nsec * $2; }
   | tSEC_UNIT
       { pc->rel_seconds += $1; }
+  | relunit_snumber
+  ;
+
+relunit_snumber:
+    tSNUMBER tYEAR_UNIT
+      { pc->rel_year += $1.value * $2; }
+  | tSNUMBER tMONTH_UNIT
+      { pc->rel_month += $1.value * $2; }
+  | tSNUMBER tDAY_UNIT
+      { pc->rel_day += $1.value * $2; }
+  | tSNUMBER tHOUR_UNIT
+      { pc->rel_hour += $1.value * $2; }
+  | tSNUMBER tMINUTE_UNIT
+      { pc->rel_minutes += $1.value * $2; }
+  | tSNUMBER tSEC_UNIT
+      { pc->rel_seconds += $1.value * $2; }
   ;
 
 seconds: signed_seconds | unsigned_seconds;
@@ -504,7 +517,7 @@
 number:
     tUNUMBER
       {
-       if (pc->dates_seen
+       if (pc->dates_seen && ! pc->year.digits
            && ! pc->rels_seen && (pc->times_seen || 2 < $1.digits))
          pc->year = $1;
        else
@@ -638,6 +651,17 @@
   { NULL, 0, 0 }
 };
 
+/* The universal time zone table.  These labels can be used even for
+   time stamps that would not otherwise be valid, e.g., GMT time
+   stamps in London during summer.  */
+static table const universal_time_zone_table[] =
+{
+  { "GMT",     tZONE,     HOUR ( 0) }, /* Greenwich Mean */
+  { "UT",      tZONE,     HOUR ( 0) }, /* Universal (Coordinated) */
+  { "UTC",     tZONE,     HOUR ( 0) },
+  { NULL, 0, 0 }
+};
+
 /* The time zone table.  This table is necessarily incomplete, as time
    zone abbreviations are ambiguous; e.g. Australians interpret "EST"
    as Eastern time in Australia, not as US Eastern Standard Time.
@@ -645,9 +669,6 @@
    abbreviations; use numeric abbreviations like `-0500' instead.  */
 static table const time_zone_table[] =
 {
-  { "GMT",     tZONE,     HOUR ( 0) }, /* Greenwich Mean */
-  { "UT",      tZONE,     HOUR ( 0) }, /* Universal (Coordinated) */
-  { "UTC",     tZONE,     HOUR ( 0) },
   { "WET",     tZONE,     HOUR ( 0) }, /* Western European */
   { "WEST",    tDAYZONE,  HOUR ( 0) }, /* Western European Summer */
   { "BST",     tDAYZONE,  HOUR ( 0) }, /* British Summer */
@@ -695,7 +716,7 @@
   { "GST",     tZONE,     HOUR (10) }, /* Guam Standard */
   { "NZST",    tZONE,     HOUR (12) }, /* New Zealand Standard */
   { "NZDT",    tDAYZONE,  HOUR (12) }, /* New Zealand Daylight */
-  { NULL, 0, 0  }
+  { NULL, 0, 0 }
 };
 
 /* Military time zone table. */
@@ -780,7 +801,12 @@
 {
   table const *tp;
 
-  /* Try local zone abbreviations first; they're more likely to be right.  */
+  for (tp = universal_time_zone_table; tp->name; tp++)
+    if (strcmp (name, tp->name) == 0)
+      return tp;
+
+  /* Try local zone abbreviations before those in time_zone_table, as
+     the local ones are more likely to be right.  */
   for (tp = pc->local_time_zone_table; tp->name; tp++)
     if (strcmp (name, tp->name) == 0)
       return tp;
@@ -1179,7 +1205,7 @@
   pc.input = p;
   pc.year.value = tmp->tm_year;
   pc.year.value += TM_YEAR_BASE;
-  pc.year.digits = 4;
+  pc.year.digits = 0;
   pc.month = tmp->tm_mon + 1;
   pc.day = tmp->tm_mday;
   pc.hour = tmp->tm_hour;
@@ -1197,11 +1223,12 @@
   pc.rel_month = 0;
   pc.rel_year = 0;
   pc.timespec_seen = false;
+  pc.rels_seen = false;
   pc.dates_seen = 0;
   pc.days_seen = 0;
-  pc.rels_seen = 0;
   pc.times_seen = 0;
   pc.local_zones_seen = 0;
+  pc.dsts_seen = 0;
   pc.zones_seen = 0;
 
 #if HAVE_STRUCT_TM_TM_ZONE
@@ -1269,9 +1296,8 @@
     *result = pc.seconds;
   else
     {
-      if (1 < pc.times_seen || 1 < pc.dates_seen || 1 < pc.days_seen
-         || 1 < (pc.local_zones_seen + pc.zones_seen)
-         || (pc.local_zones_seen && 1 < pc.local_isdst))
+      if (1 < (pc.times_seen | pc.dates_seen | pc.days_seen | pc.dsts_seen
+              | (pc.local_zones_seen + pc.zones_seen)))
        goto fail;
 
       tm.tm_year = to_year (pc.year) - TM_YEAR_BASE;
@@ -1292,7 +1318,7 @@
        }
 
       /* Let mktime deduce tm_isdst if we have an absolute time stamp.  */
-      if (pc.dates_seen | pc.days_seen | pc.times_seen)
+      if (!pc.rels_seen)
        tm.tm_isdst = -1;
 
       /* But if the input explicitly specifies local time with or without
--- /home/cvs/shishi/gl/getdomainname.c 2003/10/16 10:53:29     1.2
+++ /home/cvs/shishi/gl/getdomainname.c 2005/05/26 15:07:53     1.3
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 /* Written by Simon Josefsson.  */
 
--- /home/cvs/shishi/gl/getdomainname.h 2003/10/16 10:53:29     1.2
+++ /home/cvs/shishi/gl/getdomainname.h 2005/05/26 15:07:53     1.3
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifndef _GETDOMAINNAME_H
 #define _GETDOMAINNAME_H
--- /home/cvs/shishi/gl/gethostname.c   2003/09/09 09:00:50     1.2
+++ /home/cvs/shishi/gl/gethostname.c   2005/05/26 15:07:53     1.3
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 /* David MacKenzie <address@hidden> */
 
--- /home/cvs/shishi/gl/getline.c       2004/07/02 09:19:39     1.2
+++ /home/cvs/shishi/gl/getline.c       2005/05/26 15:07:53     1.3
@@ -15,7 +15,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 /* Written by Jan Brittenson, address@hidden  */
 
--- /home/cvs/shishi/gl/getline.h       2003/10/16 10:53:29     1.1
+++ /home/cvs/shishi/gl/getline.h       2005/05/26 15:07:53     1.2
@@ -15,7 +15,7 @@
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. 
 */
 
 #ifndef GETLINE_H_
 # define GETLINE_H_ 1
--- /home/cvs/shishi/gl/getndelim2.c    2004/10/05 18:54:41     1.5
+++ /home/cvs/shishi/gl/getndelim2.c    2005/05/26 15:07:53     1.6
@@ -16,7 +16,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 /* Originally written by Jan Brittenson, address@hidden  */
 
--- /home/cvs/shishi/gl/getndelim2.h    2004/07/02 09:19:39     1.2
+++ /home/cvs/shishi/gl/getndelim2.h    2005/05/26 15:07:53     1.3
@@ -15,7 +15,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifndef GETNDELIM2_H
 #define GETNDELIM2_H 1
--- /home/cvs/shishi/gl/getopt.c        2004/11/19 14:04:23     1.7
+++ /home/cvs/shishi/gl/getopt.c        2005/05/26 15:07:53     1.8
@@ -18,7 +18,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 /* This tells Alpha OSF/1 not to define a getopt prototype in <stdio.h>.
    Ditto for AIX 3.2 and <stdlib.h>.  */
--- /home/cvs/shishi/gl/getopt1.c       2004/11/19 14:04:23     1.7
+++ /home/cvs/shishi/gl/getopt1.c       2005/05/26 15:07:54     1.8
@@ -15,7 +15,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
--- /home/cvs/shishi/gl/getopt_.h       2004/11/29 01:55:42     1.6
+++ /home/cvs/shishi/gl/getopt_.h       2005/05/26 15:07:54     1.7
@@ -15,7 +15,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifndef _GETOPT_H
 
--- /home/cvs/shishi/gl/getopt_int.h    2004/11/19 14:04:23     1.3
+++ /home/cvs/shishi/gl/getopt_int.h    2005/05/26 15:07:54     1.4
@@ -15,7 +15,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifndef _GETOPT_INT_H
 #define _GETOPT_INT_H  1
--- /home/cvs/shishi/gl/getpass.c       2004/11/08 14:50:17     1.4
+++ /home/cvs/shishi/gl/getpass.c       2005/05/26 15:07:54     1.5
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #if HAVE_CONFIG_H
 # include <config.h>
--- /home/cvs/shishi/gl/getpass.h       2004/09/02 19:43:29     1.1
+++ /home/cvs/shishi/gl/getpass.h       2005/05/26 15:07:54     1.2
@@ -14,18 +14,18 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifndef GETPASS_H
-#define GETPASS_H
+# define GETPASS_H
 
 /* Get getpass declaration, if available.  */
-#include <unistd.h>
+# include <unistd.h>
 
-#if defined HAVE_DECL_GETPASS && !HAVE_DECL_GETPASS
+# if defined HAVE_DECL_GETPASS && !HAVE_DECL_GETPASS
 /* Read a password of arbitrary length from /dev/tty or stdin.  */
 char *getpass (const char *prompt);
 
-#endif
+# endif
 
 #endif /* GETPASS_H */
--- /home/cvs/shishi/gl/getsubopt.c     2004/10/05 18:54:41     1.3
+++ /home/cvs/shishi/gl/getsubopt.c     2005/05/26 15:07:54     1.4
@@ -15,7 +15,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #include <stdlib.h>
 #include <string.h>
--- /home/cvs/shishi/gl/getsubopt.h     2004/08/07 14:31:58     1.2
+++ /home/cvs/shishi/gl/getsubopt.h     2005/05/26 15:07:54     1.3
@@ -2,20 +2,19 @@
    Copyright (C) 2004 Free Software Foundation, Inc.
    Contributed by Simon Josefsson <address@hidden>, 2004.
 
-   The GNU C Library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Lesser General Public
-   License as published by the Free Software Foundation; either
-   version 2.1 of the License, or (at your option) any later version.
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2, or (at your option)
+   any later version.
 
-   The GNU C Library is distributed in the hope that it will be useful,
+   This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Lesser General Public License for more details.
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
-   You should have received a copy of the GNU Lesser General Public
-   License along with the GNU C Library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307 USA.  */
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software Foundation,
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 /* Assuming *OPTIONP is a comma separated list of elements of the form
    "token" or "token=value", getsubopt parses the first of these elements.
--- /home/cvs/shishi/gl/gettext.h       2005/03/14 14:32:14     1.3
+++ /home/cvs/shishi/gl/gettext.h       2005/05/26 15:07:54     1.4
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifndef _LIBGETTEXT_H
 #define _LIBGETTEXT_H 1
--- /home/cvs/shishi/gl/gettime.c       2005/03/14 14:32:14     1.3
+++ /home/cvs/shishi/gl/gettime.c       2005/05/26 15:07:54     1.4
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 /* Written by Paul Eggert.  */
 
--- /home/cvs/shishi/gl/gettimeofday.c  2004/04/18 12:10:19     1.1
+++ /home/cvs/shishi/gl/gettimeofday.c  2005/05/26 15:07:54     1.2
@@ -16,7 +16,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 /* written by Jim Meyering */
 
--- /home/cvs/shishi/gl/printf-args.c   2003/11/30 18:59:44     1.3
+++ /home/cvs/shishi/gl/printf-args.c   2005/05/26 15:07:54     1.4
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
--- /home/cvs/shishi/gl/printf-args.h   2003/11/30 18:59:44     1.3
+++ /home/cvs/shishi/gl/printf-args.h   2005/05/26 15:07:54     1.4
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifndef _PRINTF_ARGS_H
 #define _PRINTF_ARGS_H
--- /home/cvs/shishi/gl/printf-parse.c  2003/11/30 18:59:44     1.3
+++ /home/cvs/shishi/gl/printf-parse.c  2005/05/26 15:07:54     1.4
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
--- /home/cvs/shishi/gl/printf-parse.h  2003/11/30 18:59:44     1.3
+++ /home/cvs/shishi/gl/printf-parse.h  2005/05/26 15:07:54     1.4
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifndef _PRINTF_PARSE_H
 #define _PRINTF_PARSE_H
--- /home/cvs/shishi/gl/progname.c      2005/03/14 14:32:14     1.6
+++ /home/cvs/shishi/gl/progname.c      2005/05/26 15:07:54     1.7
@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 
 #ifdef HAVE_CONFIG_H
--- /home/cvs/shishi/gl/progname.h      2004/11/12 13:18:49     1.8
+++ /home/cvs/shishi/gl/progname.h      2005/05/26 15:07:54     1.9
@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifndef _PROGNAME_H
 #define _PROGNAME_H
--- /home/cvs/shishi/gl/readlink.c      2004/11/08 14:50:17     1.2
+++ /home/cvs/shishi/gl/readlink.c      2005/05/26 15:07:54     1.3
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #if HAVE_CONFIG_H
 # include <config.h>
--- /home/cvs/shishi/gl/realloc.c       2004/11/19 14:04:23     1.4
+++ /home/cvs/shishi/gl/realloc.c       2005/05/26 15:07:54     1.5
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 /* written by Jim Meyering */
 
--- /home/cvs/shishi/gl/setenv.c        2005/03/14 14:32:14     1.6
+++ /home/cvs/shishi/gl/setenv.c        2005/05/26 15:07:54     1.7
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #if HAVE_CONFIG_H
 # include <config.h>
--- /home/cvs/shishi/gl/setenv.h        2004/11/08 14:50:17     1.3
+++ /home/cvs/shishi/gl/setenv.h        2005/05/26 15:07:54     1.4
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #if HAVE_SETENV || HAVE_UNSETENV
 
--- /home/cvs/shishi/gl/stdbool_.h      2003/11/22 07:10:04     1.2
+++ /home/cvs/shishi/gl/stdbool_.h      2005/05/26 15:07:54     1.3
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifndef _STDBOOL_H
 #define _STDBOOL_H
--- /home/cvs/shishi/gl/strcase.h       2004/08/01 18:03:47     1.2
+++ /home/cvs/shishi/gl/strcase.h       2005/05/26 15:07:54     1.3
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifndef _STRCASE_H
 #define _STRCASE_H
--- /home/cvs/shishi/gl/strcasecmp.c    2003/07/04 21:47:50     1.1
+++ /home/cvs/shishi/gl/strcasecmp.c    2005/05/26 15:07:54     1.2
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #if HAVE_CONFIG_H
 # include <config.h>
--- /home/cvs/shishi/gl/strchrnul.c     2003/09/14 21:10:11     1.2
+++ /home/cvs/shishi/gl/strchrnul.c     2005/05/26 15:07:54     1.3
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 /* Specification.  */
 #include "strchrnul.h"
--- /home/cvs/shishi/gl/strchrnul.h     2003/07/04 21:47:50     1.1
+++ /home/cvs/shishi/gl/strchrnul.h     2005/05/26 15:07:54     1.2
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #if HAVE_STRCHRNUL
 
--- /home/cvs/shishi/gl/strdup.c        2004/08/07 14:06:59     1.4
+++ /home/cvs/shishi/gl/strdup.c        2005/05/26 15:07:54     1.5
@@ -15,7 +15,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
--- /home/cvs/shishi/gl/strdup.h        2004/08/07 14:06:59     1.2
+++ /home/cvs/shishi/gl/strdup.h        2005/05/26 15:07:54     1.3
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifndef STRDUP_H_
 #define STRDUP_H_
--- /home/cvs/shishi/gl/strndup.c       2005/03/21 22:11:17     1.3
+++ /home/cvs/shishi/gl/strndup.c       2005/05/26 15:07:54     1.4
@@ -15,7 +15,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
--- /home/cvs/shishi/gl/strndup.h       2003/08/22 17:48:49     1.1
+++ /home/cvs/shishi/gl/strndup.h       2005/05/26 15:07:54     1.2
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #if HAVE_STRNDUP
 
--- /home/cvs/shishi/gl/strnlen.c       2003/09/14 21:10:11     1.2
+++ /home/cvs/shishi/gl/strnlen.c       2005/05/26 15:07:54     1.3
@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #if HAVE_CONFIG_H
 # include <config.h>
--- /home/cvs/shishi/gl/strtok_r.c      2004/11/19 14:07:14     1.5
+++ /home/cvs/shishi/gl/strtok_r.c      2005/05/26 15:07:54     1.6
@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
--- /home/cvs/shishi/gl/strtok_r.h      2004/11/19 14:07:14     1.2
+++ /home/cvs/shishi/gl/strtok_r.h      2005/05/26 15:07:54     1.3
@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifndef STRTOK_R_H
 #define STRTOK_R_H
--- /home/cvs/shishi/gl/time_r.c        2003/09/08 11:52:45     1.2
+++ /home/cvs/shishi/gl/time_r.c        2005/05/26 15:07:54     1.3
@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 /* Written by Paul Eggert.  */
 
--- /home/cvs/shishi/gl/time_r.h        2003/09/06 22:24:14     1.1
+++ /home/cvs/shishi/gl/time_r.h        2005/05/26 15:07:54     1.2
@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 /* Written by Paul Eggert.  */
 
--- /home/cvs/shishi/gl/timegm.c        2004/04/18 12:10:19     1.7
+++ /home/cvs/shishi/gl/timegm.c        2005/05/26 15:07:54     1.8
@@ -15,7 +15,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
--- /home/cvs/shishi/gl/timegm.h        2005/03/14 14:32:14     1.4
+++ /home/cvs/shishi/gl/timegm.h        2005/05/26 15:07:54     1.5
@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #include <time.h>
 
--- /home/cvs/shishi/gl/timespec.h      2005/03/14 14:32:14     1.2
+++ /home/cvs/shishi/gl/timespec.h      2005/05/26 15:07:54     1.3
@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #if ! defined TIMESPEC_H
 # define TIMESPEC_H
--- /home/cvs/shishi/gl/unsetenv.c      2004/04/18 12:10:19     1.4
+++ /home/cvs/shishi/gl/unsetenv.c      2005/05/26 15:07:54     1.5
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #if HAVE_CONFIG_H
 # include <config.h>
--- /home/cvs/shishi/gl/vasnprintf.c    2005/03/14 14:32:14     1.9
+++ /home/cvs/shishi/gl/vasnprintf.c    2005/05/26 15:07:54     1.10
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 /* Tell glibc's <stdio.h> to provide a prototype for snprintf().
    This must come before <config.h> because <config.h> may include
--- /home/cvs/shishi/gl/vasnprintf.h    2004/10/05 18:54:41     1.3
+++ /home/cvs/shishi/gl/vasnprintf.h    2005/05/26 15:07:54     1.4
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifndef _VASNPRINTF_H
 #define _VASNPRINTF_H
--- /home/cvs/shishi/gl/vasprintf.c     2005/03/14 14:32:14     1.5
+++ /home/cvs/shishi/gl/vasprintf.c     2005/05/26 15:07:54     1.6
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
--- /home/cvs/shishi/gl/vasprintf.h     2003/08/22 17:48:49     1.2
+++ /home/cvs/shishi/gl/vasprintf.h     2005/05/26 15:07:54     1.3
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifndef _VASPRINTF_H
 #define _VASPRINTF_H
--- /home/cvs/shishi/gl/xalloc.h        2004/10/05 18:54:41     1.8
+++ /home/cvs/shishi/gl/xalloc.h        2005/05/26 15:07:54     1.9
@@ -15,7 +15,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifndef XALLOC_H_
 # define XALLOC_H_
--- /home/cvs/shishi/gl/xasprintf.c     2004/12/02 03:09:47     1.1
+++ /home/cvs/shishi/gl/xasprintf.c     2005/05/26 15:07:54     1.2
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
--- /home/cvs/shishi/gl/xgetdomainname.c        2004/08/07 14:06:59     1.4
+++ /home/cvs/shishi/gl/xgetdomainname.c        2005/05/26 15:07:54     1.5
@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 /* Based on xgethostname.c, written by Jim Meyering.  */
 
--- /home/cvs/shishi/gl/xgetdomainname.h        2003/10/16 10:53:29     1.2
+++ /home/cvs/shishi/gl/xgetdomainname.h        2005/05/26 15:07:54     1.3
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifndef _XGETDOMAINNAME_H
 #define _XGETDOMAINNAME_H
--- /home/cvs/shishi/gl/xgethostname.c  2005/03/14 14:32:14     1.4
+++ /home/cvs/shishi/gl/xgethostname.c  2005/05/26 15:07:54     1.5
@@ -15,7 +15,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 /* written by Jim Meyering */
 
--- /home/cvs/shishi/gl/xmalloc.c       2004/10/05 18:54:41     1.9
+++ /home/cvs/shishi/gl/xmalloc.c       2005/05/26 15:07:54     1.10
@@ -15,7 +15,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #if HAVE_CONFIG_H
 # include <config.h>
--- /home/cvs/shishi/gl/xreadlink.c     2004/11/08 14:50:17     1.5
+++ /home/cvs/shishi/gl/xreadlink.c     2005/05/26 15:07:54     1.6
@@ -15,7 +15,7 @@
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 /* Written by Jim Meyering <address@hidden>  */
 
--- /home/cvs/shishi/gl/xreadlink.h     2004/07/02 09:19:40     1.2
+++ /home/cvs/shishi/gl/xreadlink.h     2005/05/26 15:07:54     1.3
@@ -15,7 +15,7 @@
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 /* Written by Jim Meyering <address@hidden>  */
 
--- /home/cvs/shishi/gl/xsize.h 2003/11/30 18:59:44     1.1
+++ /home/cvs/shishi/gl/xsize.h 2005/05/26 15:07:54     1.2
@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifndef _XSIZE_H
 #define _XSIZE_H
--- /home/cvs/shishi/gl/xstrndup.c      2003/08/22 17:48:49     1.2
+++ /home/cvs/shishi/gl/xstrndup.c      2005/05/26 15:07:54     1.3
@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #if HAVE_CONFIG_H
 # include <config.h>
--- /home/cvs/shishi/gl/xstrndup.h      2003/08/22 17:48:49     1.1
+++ /home/cvs/shishi/gl/xstrndup.h      2005/05/26 15:07:54     1.2
@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #include <stddef.h>
 
--- /home/cvs/shishi/gl/xvasprintf.c    2004/12/02 03:09:47     1.1
+++ /home/cvs/shishi/gl/xvasprintf.c    2005/05/26 15:07:54     1.2
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
--- /home/cvs/shishi/gl/xvasprintf.h    2004/12/02 03:09:47     1.1
+++ /home/cvs/shishi/gl/xvasprintf.h    2005/05/26 15:07:54     1.2
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifndef _XVASPRINTF_H
 #define _XVASPRINTF_H





reply via email to

[Prev in Thread] Current Thread [Next in Thread]
--- /home/cvs/shishi/gl/mktime.c        2005/03/21 22:11:17     1.9
+++ /home/cvs/shishi/gl/mktime.c        2005/05/26 15:07:54     1.10
@@ -16,7 +16,7 @@
 
    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 /* Define this to have a standalone program to test this implementation of
    mktime.  */
@@ -68,9 +68,9 @@
    an integer.  */
 #define TYPE_IS_INTEGER(t) ((t) 1.5 == 1)
 
-/* True if negative values of the signed integer type T use twos
-   complement, ones complement, or signed magnitude representation,
-   respectively.  Much GNU code assumes twos complement, but some
+/* True if negative values of the signed integer type T use two's
+   complement, ones' complement, or signed magnitude representation,
+   respectively.  Much GNU code assumes two's complement, but some
    people like to be portable to all possible C hosts.  */
 #define TYPE_TWOS_COMPLEMENT(t) ((t) ~ (t) 0 == (t) -1)
 #define TYPE_ONES_COMPLEMENT(t) ((t) ~ (t) 0 == 0)